@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: JadortServiceTest.java 5667 2009-12-02 10:10:51Z alitokmen $
+ * $Id: JadortServiceTest.java 6155 2010-03-12 18:18:46Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.tests.implementation;
@@ -35,7 +35,9 @@ import java.util.UUID;
 
 import javax.naming.Context;
 import javax.naming.InitialContext;
+import javax.naming.NamingException;
 
+import org.apache.commons.io.FileUtils;
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -45,11 +47,13 @@ import org.junit.Test;
 import org.ow2.jasmine.jadort.api.IJadortService;
 import org.ow2.jasmine.jadort.api.JadortServiceException;
 import org.ow2.jasmine.jadort.api.IJadortService.OperationType;
+import org.ow2.jasmine.jadort.api.entities.deployment.ApplicationBean;
 import org.ow2.jasmine.jadort.api.entities.deployment.OperationStateBean;
 import org.ow2.jasmine.jadort.api.entities.deployment.ServerProgressBean;
 import org.ow2.jasmine.jadort.api.entities.deployment.ServerProgressState;
 import org.ow2.jasmine.jadort.api.entities.deployment.WorkerProgressBean;
 import org.ow2.jasmine.jadort.api.entities.deployment.WorkerProgressState;
+import org.ow2.jasmine.jadort.api.entities.deployment.ApplicationBean.ApplicationType;
 import org.ow2.jasmine.jadort.api.entities.deployment.OperationStateBean.ActionState;
 import org.ow2.jasmine.jadort.api.entities.deployment.OperationStateBean.Step;
 import org.ow2.jasmine.jadort.api.entities.topology.GroupBean;
@@ -58,6 +62,8 @@ import org.ow2.jasmine.jadort.service.action.DummyServerAction;
 import org.ow2.jasmine.jadort.service.action.DummyWorkerAction;
 import org.ow2.jasmine.jadort.service.implementation.JMSSender;
 import org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean;
+import org.ow2.util.archive.api.ArchiveException;
+import org.ow2.util.ee.deploy.impl.helper.DeployableHelperException;
 
 /**
  * Tests the JaDOrT service implementation.
@@ -80,6 +86,11 @@ public class JadortServiceTest {
      */
     private static final String INITIAL_CONTEXT_FACTORY = "org.ow2.carol.jndi.spi.MultiOrbInitialContextFactory";
 
+    /**
+     * Timeout (in seconds) for JaDOrT to initialize.
+     */
+    private static final int INITIALIZE_TIMEOUT = 30;
+
     /**
      * Timeout (in seconds) for each serverProgress test.
      */
@@ -123,8 +134,20 @@ public class JadortServiceTest {
             Hashtable<String, Object> env = new Hashtable<String, Object>();
             env.put(Context.INITIAL_CONTEXT_FACTORY, JadortServiceTest.INITIAL_CONTEXT_FACTORY);
             env.put(Context.PROVIDER_URL, "rmi://localhost:" + carolPort);
-            Context context = new InitialContext(env);
-            result = (IJadortService) context.lookup(IJadortService.EJB_JNDI_NAME);
+            final long timeout = System.currentTimeMillis() + JadortServiceTest.INITIALIZE_TIMEOUT * 1000;
+            while (true) {
+                try {
+                    Context context = new InitialContext(env);
+                    result = (IJadortService) context.lookup(IJadortService.EJB_JNDI_NAME);
+                    break;
+                } catch (NamingException e) {
+                    if (System.currentTimeMillis() > timeout) {
+                        throw e;
+                    } else {
+                        Thread.sleep(1000);
+                    }
+                }
+            }
         } else {
             DummyServerAction.MAX_SLEEP = 1;
             DummyWorkerAction.MAX_SLEEP = 1;
@@ -180,6 +203,55 @@ public class JadortServiceTest {
         this.jadortService = null;
     }
 
+    /**
+     * Test method for
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#createApplicationBeanFromFile(java.io.File)}
+     * with a valid file.
+     */
+    @Test
+    public void testApplicationBeanWithValidFile() throws Exception {
+        File file = new File("src/test/resources/application1.ear");
+
+        ApplicationBean application = JadortServiceStatefulBean.createApplicationBeanFromFile(file);
+        Assert.assertNotNull(application);
+        Assert.assertEquals(file, application.getFile());
+        Assert.assertEquals(ApplicationType.JAVA_EE, application.getApplicationType());
+    }
+
+    /**
+     * Test method for
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#createApplicationBeanFromFile(java.io.File)}
+     * with an invalid file.
+     */
+    @Test
+    public void testApplicationBeanWithInvalidFile() throws Exception {
+        File file = new File("src/test/resources/noApplication.war");
+
+        try {
+            JadortServiceStatefulBean.createApplicationBeanFromFile(file);
+            Assert.fail();
+        } catch (DeployableHelperException e) {
+            // That failure is expected
+        } catch (ArchiveException e) {
+            // That failure is expected
+        }
+    }
+
+    /**
+     * Test method for
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#createApplicationBeanFromFile(java.io.File)}
+     * with a bundle.
+     */
+    @Test
+    public void testApplicationBeanWithBundle() throws Exception {
+        File file = new File("src/test/resources/ow2-util-jmx-api-1.0.18.jar");
+
+        ApplicationBean application = JadortServiceStatefulBean.createApplicationBeanFromFile(file);
+        Assert.assertNotNull(application);
+        Assert.assertEquals(file, application.getFile());
+        Assert.assertEquals(ApplicationType.OSGI, application.getApplicationType());
+    }
+
     /**
      * Test method for
      * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#createNewOperation(String)}
@@ -231,8 +303,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file with many different kinds of servers.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML with many different kinds of servers.
      */
     @Test
     public void testValidTopology_heterogeneousServers() throws Exception {
@@ -241,7 +313,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("../jadort-documentation-and-samples/src/main/resources/Topology with heterogeneous servers.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
         // Don't go next, we don't have that many servers in the CI !!
 
@@ -268,8 +340,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file with an OSGi server.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML with an OSGi server.
      */
     @Test
     public void testValidTopology_osgiServer() throws Exception {
@@ -278,7 +350,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("../jadort-documentation-and-samples/src/main/resources/Topology with OSGi servers.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
         // Don't go next, we don't have that many servers in the CI !!
 
@@ -300,8 +372,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid and mixed topology file.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid and mixed topology XML.
      */
     @Test
     public void testValidTopology_manyServers() throws Exception {
@@ -310,7 +382,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_manyServers.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
 
         // Don't go next, we don't have that many servers in the CI !!
@@ -318,8 +390,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file with managers and targets.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML with managers and targets.
      */
     @Test
     public void testValidTopology_manager() throws Exception {
@@ -328,7 +400,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_manager.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
         this.jadortService.next();
 
@@ -344,8 +416,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file containing VMs.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML containing VMs.
      */
     @Test
     public void testValidTopology_VM() throws Exception {
@@ -354,13 +426,13 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_VM.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file containing dummy servers.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML containing dummy servers.
      */
     @Test
     public void testValidTopology_cluster() throws Exception {
@@ -369,15 +441,15 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_cluster.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         this.jadortService.next();
         Assert.assertEquals(Step.SELECT_GROUP, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file containing dummy servers with targets.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML containing dummy servers with targets.
      */
     @Test
     public void testValidTopology_target() throws Exception {
@@ -386,15 +458,15 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_target.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         this.jadortService.next();
         Assert.assertEquals(Step.SELECT_GROUP, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file with two groups inside.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML with two groups inside.
      */
     @Test
     public void testValidTopology_manyGroups() throws Exception {
@@ -403,15 +475,15 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_manyGroups.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         this.jadortService.next();
         Assert.assertEquals(Step.SELECT_GROUP, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid topology file with no cluster .
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid topology XML with no cluster .
      */
     @Test
     public void testValidTopology_noCluster() throws Exception {
@@ -420,15 +492,15 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_noCluster.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         this.jadortService.next();
         Assert.assertEquals(Step.SELECT_GROUP, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a topology file that's in the JASMINe Deploy ME format.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a topology XML that's in the JASMINe Deploy ME format.
      */
     @Test
     public void testTopology_DeployME() throws Exception {
@@ -437,7 +509,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOKDeployME.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
 
         List<GroupBean> groups = this.jadortService.getCurrentOperation().getTopology().getGroups();
@@ -455,8 +527,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a topology file that's in the JASMINe Deploy ME format.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a topology XML that's in the JASMINe Deploy ME format.
      */
     @Test
     public void testTopology_DeployMEClustered() throws Exception {
@@ -465,7 +537,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOKDeployME_clustered.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
 
         List<GroupBean> groups = this.jadortService.getCurrentOperation().getTopology().getGroups();
@@ -483,8 +555,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a topology file that's in the JASMINe Deploy ME format.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a topology XML that's in the JASMINe Deploy ME format.
      */
     @Test
     public void testTopology_DeployMEWithClusterDaemon() throws Exception {
@@ -493,7 +565,7 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOKDeployME_cd.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
 
         List<GroupBean> groups = this.jadortService.getCurrentOperation().getTopology().getGroups();
@@ -511,8 +583,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a topology file that's in the JASMINe Deploy ME format.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a topology XML that's in the JASMINe Deploy ME format.
      */
     @Test
     public void testTopology_DeployMEWithClusterDaemonWithInvalidServerList() throws Exception {
@@ -522,7 +594,7 @@ public class JadortServiceTest {
 
         File topo = new File("src/test/resources/topologyKODeployME_cd.xml");
         try {
-            this.jadortService.loadTopology(new File(topo.toURI()));
+            this.jadortService.loadTopology(FileUtils.readFileToString(topo));
             Assert.fail("loadTopology has accepted invalid topology!");
         } catch (JadortServiceException e) {
             Assert.assertTrue(e.getMessage(), e.getMessage().contains("\n\nCannot find server"));
@@ -534,8 +606,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid and old format topology file.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid and old format topology XML.
      */
     @Test
     public void testValidTopology_oldJadortFormat() throws Exception {
@@ -544,14 +616,14 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_oldJadortFormat.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a valid and old format topology file.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with a valid and old format topology XML.
      */
     @Test
     public void testValidTopology_oldDeployMEFormat() throws Exception {
@@ -560,14 +632,14 @@ public class JadortServiceTest {
         this.testCreateNewOperation();
 
         File topo = new File("src/test/resources/topologyOK_oldDeployMEFormat.xml");
-        this.jadortService.loadTopology(new File(topo.toURI()));
+        this.jadortService.loadTopology(FileUtils.readFileToString(topo));
         Assert.assertEquals(Step.INITIALIZE_TOPOLOGY, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with an invalid topology file (no server URL).
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with an invalid topology XML (no server URL).
      */
     @Test
     public void testInvalidTopology_noServerURL() throws Exception {
@@ -577,7 +649,7 @@ public class JadortServiceTest {
 
         File topo = new File("src/test/resources/topologyKO_noServerURL.xml");
         try {
-            this.jadortService.loadTopology(new File(topo.toURI()));
+            this.jadortService.loadTopology(FileUtils.readFileToString(topo));
             Assert.fail("loadTopology has accepted invalid topology!");
         } catch (JadortServiceException e) {
             // Do a call on the service to ensure it didn't die
@@ -587,8 +659,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with an invalid topology file (no worker URL).
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with an invalid topology XML (no worker URL).
      */
     @Test
     public void testInvalidTopology_noWorkerURL() throws Exception {
@@ -598,7 +670,7 @@ public class JadortServiceTest {
 
         File topo = new File("src/test/resources/topologyKO_noWorkerURL.xml");
         try {
-            this.jadortService.loadTopology(new File(topo.toURI()));
+            this.jadortService.loadTopology(FileUtils.readFileToString(topo));
             Assert.fail("loadTopology has accepted invalid topology!");
         } catch (JadortServiceException e) {
             // Do a call on the service to ensure it didn't die
@@ -608,8 +680,8 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with an invalid topology file (wrong balancer).
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with an invalid topology XML (wrong balancer).
      */
     @Test
     public void testInvalidTopology_wrongBalancer() throws Exception {
@@ -619,7 +691,7 @@ public class JadortServiceTest {
 
         File topo = new File("src/test/resources/topologyKO_wrongBalancer.xml");
         try {
-            this.jadortService.loadTopology(new File(topo.toURI()));
+            this.jadortService.loadTopology(FileUtils.readFileToString(topo));
             Assert.fail("loadTopology has accepted invalid topology!");
         } catch (JadortServiceException e) {
             // Do a call on the service to ensure it didn't die
@@ -629,18 +701,17 @@ public class JadortServiceTest {
 
     /**
      * Test method for
-     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(File)}
-     * with a non-existing topology file.
+     * {@link org.ow2.jasmine.jadort.service.implementation.JadortServiceStatefulBean#loadTopology(String)}
+     * with an XML as topology.
      */
     @Test
-    public void testNonExistingTopology() throws Exception {
+    public void testInvalidXMLTopology() throws Exception {
         System.out.println("JadortServiceTest.testNonExistingTopology");
 
         this.testCreateNewOperation();
 
-        File topo = new File("/dev/null");
         try {
-            this.jadortService.loadTopology(new File(topo.toURI()));
+            this.jadortService.loadTopology("this is not XML");
             Assert.fail("loadTopology has accepted a non-existing file!");
         } catch (JadortServiceException e) {
             // Do a call on the service to ensure it didn't die
@@ -1417,7 +1488,7 @@ public class JadortServiceTest {
     private void maintainServersCluster() throws Exception {
         System.out.println("\tJadortServiceTest.maintainServersCluster");
 
-        // In our test topology file we have 2 workers per server
+        // In our test topology XML we have 2 workers per server
         Assert.assertEquals(2 * this.jadortService.getCurrentOperation().getServerProgressList().size(), this.jadortService
             .getCurrentOperation().getWorkerProgressList().size());
 
@@ -1507,7 +1578,7 @@ public class JadortServiceTest {
     private void maintainServersNoCluster() throws Exception {
         System.out.println("\tJadortServiceTest.maintainServersNoCluster");
 
-        // In our test topology file we have 2 workers per server
+        // In our test topology XML we have 2 workers per server
         Assert.assertEquals(2 * this.jadortService.getCurrentOperation().getServerProgressList().size(), this.jadortService
             .getCurrentOperation().getWorkerProgressList().size());
 
